==> eewiki-0.9.tar.gz: eewiki/src/org/j69/eewiki/action/UploadForm.java <==
package org.j69.eewiki.action;

import java.io.UnsupportedEncodingException;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

import org.apache.struts.upload.FormFile;

/**
 * UploadForm.java created by EasyStruts - XsltGen.
 * http://easystruts.sf.net
 * created on 06-07-2003
 *
 * XDoclet definition:
 * @struts:form name="UploadForm"
 */
public class UploadForm extends ActionForm {

    /** action property */
    private String action;

    /** fileName property */
    private String fileName;

    /** pid property */
    private String pid;

    /** uploadFile property */
    private FormFile uploadFile;

    /**
     * Method validate
     * @param ActionMapping mapping
     * @param HttpServletRequest request
     * @return ActionErrors
     */
    public ActionErrors validate(
        ActionMapping mapping,
        HttpServletRequest request) {

        throw new UnsupportedOperationException("Generated method 'validate(...)' not implemented.");
    }

    /**
     * Returns the action.
     * @return String
     */
    public String getAction() {
        return action;
    }

    /**
     * Set the action.
     * @param action The action to set
     */
    public void setAction(String action) {
        this.action = action;
    }

    /**
     * Returns the fileName.
     * @return String
     */
    public String getFileName() throws UnsupportedEncodingException {
    	//うーん（涙）日本語ファイル名で化ける文字がある...
		String fname =  new String(uploadFile.getFileName().getBytes(), "UTF-8");
		////String fname =  uploadFile.getFileName();
        return fname;
    }

    /**
     * Set the fileName.
     * @param fileName The fileName to set
     */
    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    /**
     * Returns the pid.
     * @return String
     */
    public String getPid() {
        return pid;
    }

    /**
     * Set the pid.
     * @param pid The pid to set
     */
    public void setPid(String pid) {
        this.pid = pid;
    }

    /**
     * Set the uploadFile.
     * @param file
     */
    public void setUploadFile(FormFile uploadFile) {
        this.uploadFile = uploadFile;
    }

    /**
     * Returns the uploadFile.
     * @return
     */
    public FormFile getUploadFile() {
        return uploadFile;
    }

}

==> eewiki-0.9.2.tar.gz: eewiki/src/org/j69/eewiki/action/UploadForm.java <==
package org.j69.eewiki.action;

import java.io.UnsupportedEncodingException;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

import org.apache.struts.upload.FormFile;

/**
 * UploadForm.java created by EasyStruts - XsltGen.
 * http://easystruts.sf.net
 * created on 06-07-2003
 *
 * XDoclet definition:
 * @struts:form name="UploadForm"
 */
public class UploadForm extends ActionForm {

    /** action property */
    private String action;

    /** fileName property */
    private String fileName;

    /** pid property */
    private String pid;

    /** uploadFile property */
    private FormFile uploadFile;

    /**
     * Method validate
     * @param ActionMapping mapping
     * @param HttpServletRequest request
     * @return ActionErrors
     */
    public ActionErrors validate(
        ActionMapping mapping,
        HttpServletRequest request) {

        throw new UnsupportedOperationException("Generated method 'validate(...)' not implemented.");
    }

    /**
     * Returns the action.
     * @return String
     */
    public String getAction() {
        return action;
    }

    /**
     * Set the action.
     * @param action The action to set
     */
    public void setAction(String action) {
        this.action = action;
    }

    /**
     * Returns the fileName.
     * @return String
     */
    public String getFileName() throws UnsupportedEncodingException {
		String fname =  uploadFile.getFileName();
        return fname;
    }

    /**
     * Set the fileName.
     * @param fileName The fileName to set
     */
    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    /**
     * Returns the pid.
     * @return String
     */
    public String getPid() {
        return pid;
    }

    /**
     * Set the pid.
     * @param pid The pid to set
     */
    public void setPid(String pid) {
        this.pid = pid;
    }

    /**
     * Set the uploadFile.
     * @param file
     */
    public void setUploadFile(FormFile uploadFile) {
        this.uploadFile = uploadFile;
    }

    /**
     * Returns the uploadFile.
     * @return
     */
    public FormFile getUploadFile() {
        return uploadFile;
    }

	/* (non-Javadoc)
	 * @see org.apache.struts.action.ActionForm#reset(org.apache.struts.action.ActionMapping, javax.servlet.ServletRequest)
	 */
	public void reset(ActionMapping mapping, ServletRequest req) {
		try {
			req.setCharacterEncoding("UTF-8");
		}
		catch(Exception e) {
			e.getMessage();
		}
	}
}
